===============================
Rabbit Hole
===============================

.. image:: https://img.shields.io/badge/License-MIT-blue.svg
    :target: https://opensource.org/licenses/MIT
    :alt: License

.. image:: https://img.shields.io/pypi/v/rabbithole.svg
    :target: https://pypi.python.org/pypi/rabbithole
    :alt: PyPI version

.. image:: https://img.shields.io/travis/jcollado/rabbithole.svg
    :target: https://travis-ci.org/jcollado/rabbithole
    :alt: Continuous integration

.. image:: https://coveralls.io/repos/github/jcollado/rabbithole/badge.svg?branch=master
    :target: https://coveralls.io/github/jcollado/rabbithole?branch=master
    :alt: Coverage

.. image:: https://landscape.io/github/jcollado/rabbithole/master/landscape.svg?style=flat
   :target: https://landscape.io/github/jcollado/rabbithole/master
   :alt: Code Health

.. image:: https://readthedocs.org/projects/rabbitmqhole/badge/?version=latest
    :target: https://rabbitmqhole.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/jcollado/rabbithole/shield.svg
    :target: https://pyup.io/repos/github/jcollado/rabbithole/
    :alt: Updates


Store messages from rabbitmq into a SQL database

Features
--------

* Get messages from multiple RabbitMQ exchanges
* Group messages in batches
* Write message batches to a SQL database

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

